Expyrimenter
============

.. image:: https://readthedocs.org/projects/expyrimenter/badge/?version=latest
   :alt: Documentation
   :target: http://expyrimenter.rtfd.org/en/latest/
.. image:: https://pypip.in/version/expyrimenter/badge.svg
   :alt: PyPI
   :target: https://pypi.python.org/pypi/expyrimenter
.. image:: https://travis-ci.org/cemsbr/expyrimenter.svg?branch=master
   :alt: Continuous Integration
   :target: https://travis-ci.org/cemsbr/expyrimenter
.. image:: https://img.shields.io/coveralls/cemsbr/expyrimenter.svg
   :alt: Code Coverage
   :target: https://coveralls.io/r/cemsbr/expyrimenter

Python tool to help experiment automation.
It helps to execute local and remote commands in parallel.

- Quick example and docs: `Read the Docs
  <http://expyrimenter.rtfd.org/en/latest/>`_
- Source code and issues/bug reports: `GitHub
  <https://github.com/cemsbr/expyrimenter>`_

